#!/bin/sh
#
#----------------------------------------------------------------------------
# /tmp/install.sh
#
# Creation:    19.01.2006 th
# Last Update: 10.03.2023 OJae
#
# Copyright (c) 2004-2005 Torsten Hoellermann <torsten(at)hoellie(dot)de>
# Copyright (c) 2016-2023 Olaf Jaehrling <eisfair@ojaehrling.de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License
#----------------------------------------------------------------------------

# include eislibs
. /var/install/include/eislib
. /var/install/include/configlib

package="openvpn2"
package_name="OpenVPN"
configfile="/etc/config.d/$package"

# creating needed directorys
#mecho --info "running install.sh"
mkdir -p -m 0644 /etc/openvpn/keys
mkdir -p -m 0775 /etc/openvpn/ccd
mkdir -p -m 0644 /run/openvpn
mkdir -p -m 0644 /var/log/openvpn
mkdir -p -m 0644 /usr/local/openvpn/conf

if ! grep -q setup.services.openvpn2.menu /var/install/menu/setup.services.menu
then
    # creating menu
    #mecho -info "Creating Menue"
    /var/install/bin/add-menu setup.services.menu setup.services.$package.menu $package_name
    #mecho -info "Done creating Menu"
fi

sh /var/install/config.d/openvpn2-update.sh

if [ -f "$configfile" ]
then
    . $configfile
fi


#/var/install/bin/edit -apply $package "Edit $package_name configuration"
mecho -info "Please remember: restart OpenVPN manually"
sleep  3
#sh /etc/init.d/openvpn2 restart

if [ "$OPENVPN2_SERVER_ACTIVE" = "yes" ]
then
    if [ -f /usr/local/openvpn/create_vars.sh ]
    then
        /usr/local/openvpn/create_vars.sh
    fi
fi
installed_version=`/usr/bin/eisman check openvpn2 3.0.9`
if [ -f /etc/config.d/openvpn2 ]
then
    . /etc/config.d/openvpn2
fi


if [ "$installed_version" = "new" ]
then
    if [ -f /etc/openvpn/ipp.txt ]
    then
        while [ true ]
        do
            cat /etc/openvpn/ipp.txt | while read FULL
            do
                if [ "$FULL" != "" ]
                then
                    CLIENT=`echo $FULL |awk -F"," '{print $1}'`
                    IP4=`echo $FULL |awk -F"," '{print $2}'`
                    IP6=`echo $FULL |awk -F"," '{print $3}'`
                    NET6=$OPENVPN2_IPV6_NET
                    NET6=`echo $NET6 | awk -F'/' '{print "/"$2}'`
                    NET=$OPENVPN2_IPV4_SUBNET
                    IPMAX=`ipcalc -n $IP4/30 |grep HostMax |awk '{print $2}'`
#                    IPMIN=`ipcalc -n $IP4/30 |grep HostMin |awk '{print $2}'`
                    if [ "$CLIENT" != "" ]
                    then
                        if [ ! -f /etc/openvpn/ccd/$CLIENT ]
                        then
                            echo "ifconfig-push $IPMAX $NET" >/etc/openvpn/ccd/$CLIENT
                            if [ "$IP6" != "" ]
                            then
                                echo "ifconfig-ipv6-push $IP6$NET6" >>/etc/openvpn/ccd/$CLIENT
                            fi
                        fi
                    fi
                fi
            done
            break
        done
    fi
    if [ "$START_OPENVPN2" = "yes" ]
    then
        service enable openvpn2
        systemctl daemon-reload
    fi
fi
exit 0

