#!/bin/bash
#-------------------------------------------------------------------------------
# Copyright (c) 2024 Olaf Jaehrling <eisfair[at]ojaehrling.de>
#
# Creation:     30.01.2024 OJae
# Last Update:  30.01.2024 OJae
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#-------------------------------------------------------------------------------

cd /usr/local/openvpn/keys

for cert in `ls *.pem`
do

  enddate=`openssl x509 -enddate -noout -in $cert | sed 's/notAfter=//' | awk '\
    { year=$4-2000;
      months="JanFebMarAprMayJunJulAugSepOctNovDec" ; 
      month=1+index(months, $1)/3 ; 
      day=$2; 
      hour=substr($3,1,2) ; 
      minutes=substr($3,4,2); 
      seconds=substr($3,7,2); 
      printf "%02d%02d%02d%02d%02d%02dZ", year, month, day, hour, minutes, seconds}' `

  serial=`openssl x509 -serial -noout -in $cert  |sed 's/serial=//' 2>/dev/null`
  subject=`openssl x509 -subject -noout -in $cert  |sed 's-subject=-/-;s-, -/-g;s/ //'g`
#  subject=`openssl x509 -subject -noout -in $cert  |sed 's/subject= //'`
  if [ "$serial" != "" ]
  then
      if ! [[ `echo $subject | grep CN=privatCA` ]]
      then
           echo "V	$enddate		$serial	unknown $subject"
      fi
  fi
done
