#!/bin/sh
#
#----------------------------------------------------------------------------
# /var/install/config.d/openvpn2-update.sh
#
# Creation:     16.02.2016  OJae
# Last Update:  13.11.2023  OJae
#
# Copyright (c) 2005-2023 Olaf Jaehrling <eisfair@ojaehrling.de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License
#----------------------------------------------------------------------------

# include eislibs
. /var/install/include/eislib
. /var/install/include/configlib

package="openvpn2"
package_name="OpenVPN"
configfile="/etc/config.d/$package"
checkfile='/etc/check.d/openvpn2'
checkfile2='/etc/check.d/openvpn2.exp'
defaultfile="/etc/default.d/$package"
FIRST=`echo $(($RANDOM % 60))" "$(($RANDOM % 24))`

# creating needed directorys
#mecho -info "creating directories"
mkdir -p -m 0644 /etc/openvpn/keys
mkdir -p -m 0775 /etc/openvpn/ccd
mkdir -p -m 0644 /run/openvpn
mkdir -p -m 0644 /var/log/openvpn
mkdir -p -m 0644 /usr/local/openvpn/conf

CCDPERM=`ls -lh /etc/openvpn/ | grep ccd| awk {'print $1'} | cut -c1-4`
if [ "$CCDPERM" = "drw-" ]
then
    chmod 775 /etc/openvpn/ccd
fi
. /etc/config.d/base
START_OPENVPN2='no'
OPENVPN2_HOSTNAME='me.domain.tld'      # FQDN to contact from extern
OPENVPN2_CHECK_FOR_NEW_VERSION='no'
OPENVPN2_CHECK_NEW_VERSION_CRON=$FIRST' * * *'
OPENVPN2_CHECK_NEW_VERSION_TO_ADDRESS='root@localhost'
OPENVPN2_CHECK_NEW_VERSION_FROM_ADDRESS='root@loalhost'
OPENVPN2_SERVER_ACTIVE='no'            # Activate OpenVPN-Server
OPENVPN2_SERVER_IF_TYPE='tun'          # which interface type. tun or tap?
OPENVPN2_SERVER_CERT='remote-cert-tls' # use remote-cert-tls or ns-cert-type
#OPENVPN2_SERVER_CERT_HASH='sha256'
OPENVPN2_SERVER_ENABLE_FLOAT='no'      # enable floating
OPENVPN2_SERVER_ENABLE_MSSFIX=''
OPENVPN2_SERVER_ENABLE_LEGACY_DEFAULT='no'
OPENVPN2_DHCP_DOMAIN=''                # Domainname
OPENVPN2_APPEND_LOG='no'
OPENVPN2_CLIENT_ONLY_MODE='no'
OPENVPN2_CLIENT_ONLY_REMOTE_SERVER='deine.remote.domain'
OPENVPN2_CLIENT_ONLY_NAME=''
OPENVPN2_CLIENT_ONLY_PORT='1194'          # Post to listen for icoming connections
OPENVPN2_CLIENT_ONLY_PROTOCOL='udp'       # udp or tcp
OPENVPN2_CLIENT_ONLY_IF_TYPE='tun'
OPENVPN2_CLIENT_ONLY_ENABLE_LEGACY_DEFAULT='no'
OPENVPN2_CLIENT_ONLY_CIPHER='AES-256-CBC' # cipher algorithms to use
OPENVPN2_CLIENT_ONLY_CERT='remote-cert-tls' # use remote-cert-tls or ns-cert-type
#OPENVPN2_CLIENT_ONLY_CERT_HASH='sha256'
OPENVPN2_CLIENT_ONLY_CA_OR_PKCS12='pkcs12'
OPENVPN2_CLIENT_ONLY_CA_OR_PKCS12_FILE='/usr/local/openvpn/keys/client.p12'
OPENVPN2_CLIENT_ONLY_COMPRESSION='no'
OPENVPN2_CLIENT_ONLY_HMAC_AUTH=''
OPENVPN2_CLIENT_ONLY_AUTH_USER_PASS_FILE='/etc/openvpn/client/client.auth'
OPENVPN2_CLIENT_ONLY_AUTH_USER_PASSWORD=''
OPENVPN2_CLIENT_ONLY_VERIFY_X509_NAME=''
OPENVPN2_CLIENT_ONLY_IPV4_LAN='yes' # use client ipv4 on lan site?
OPENVPN2_CLIENT_ONLY_IPV4_WAN='yes' # use client ipv4 on wan site?
OPENVPN2_CLIENT_ONLY_IPV6_LAN='no'  # use client ipv6 on lan site?
OPENVPN2_CLIENT_ONLY_IPV6_WAN='no'  # use client ipv6 on wan site?
OPENVPN2_CLIENT_ONLY_REDIRECT_IPV4='no' # redirect all ipv4 traffic into openvpn tunnel y/n
OPENVPN2_CLIENT_ONLY_REDIRECT_IPV6='no' # redirect all ipv6 traffic into openvpn tunnel y/n
OPENVPN2_CLIENT_ONLY_USE_LOCALPORT=''
OPENVPN2_CLIENT_ONLY_USE_PROXY='no'
OPENVPN2_CLIENT_ONLY_PROXY='http'
OPENVPN2_CLIENT_ONLY_PROXY_AUTH='no'
OPENVPN2_CLIENT_ONLY_PROXY_AUTH_TYPE='basic'
OPENVPN2_CLIENT_ONLY_PROXY_AUTH_USERNAME=''
OPENVPN2_CLIENT_ONLY_PROXY_AUTH_PASSWORD=''
OPENVPN2_CLIENT_ONLY_ENABLE_SCRIPTSECURITY='0'
OPENVPN2_CLIENT_ONLY_SCRIPT=''
OPENVPN2_CLIENT_ONLY_IPV4_ROUTE=''  # ipv4 Net push to specified client
OPENVPN2_CLIENT_ONLY_IPV4_NET=''
OPENVPN2_CLIENT_ONLY_IPV4_ROUTE_DEST=''
OPENVPN2_CLIENT_ONLY_IPV4_ROUTE_METRIC='1'
OPENVPN2_CLIENT_ONLY_IPV6_ROUTE=''  # ipv6 Net push to specified client
OPENVPN2_CLIENT_ONLY_IPV6_ROUTE_DEST=''
OPENVPN2_CLIENT_ONLY_IPV6_ROUTE_METRIC='1'
OPENVPN2_CLIENT_N='1'
OPENVPN2_CLIENT_1_ACTIVE='no'
OPENVPN2_CLIENT_1_NAME='client'
OPENVPN2_CLIENT_1_TYPE='windows'
OPENVPN2_CLIENT_TO_CLIENT='no'
OPENVPN2_COUNTRY='DE'                  # i.e. DE,US
OPENVPN2_PROVINCE='Niedersachsen'      # i.e. NRW,Hessen
OPENVPN2_CITY='Hannover'               # i.e. Koeln,Frankfurt
OPENVPN2_ORG='privat'                  # i.e. privat, Companyname
OPENVPN2_EMAIL='olaf@domain.tld'      # i.e. openvpn@company.com
OPENVPN2_EXPORTDIR='/public/vpn'       # Exportdirectory

###### ab hier neu ###################
### vor 1.0.14 war comp-lzo standart. das ist nun nicht mehr wenn
### das Paket neu installiert wird. bei alten Installationen
### wird comp.lzo eingetragen um die client nicht abzuschiessen
if [ -f /etc/config.d/openvpn2 ]
then
    OPENVPN2_COMPRESSION='lzo'
else
    OPENVPN2_COMPRESSION=''
fi
OPENVPN2_PORT='1194'          # Post to listen for icoming connections
OPENVPN2_PROTOCOL='udp'       # udp or tcp
OPENVPN2_CIPHER='AES-256-CBC' # cipher algorithms to use
OPENVPN2_HMAC_AUTH=''

#SERVERSETTINGS:
OPENVPN2_SERVER_ENABLE_IPV6_LAN='no'  # enable ipv6 for server on lan site
OPENVPN2_SERVER_ENABLE_IPV4_WAN='yes' # enable ipv4 for server on wan site
OPENVPN2_SERVER_ENABLE_IPV6_WAN='no'  # enable ipv6 for server on wan site
OPENVPN2_IPV4_NET='192.168.40.0'      # Net for internal ipv4 vpn net
OPENVPN2_IPV4_SUBNET='255.255.255.0'  # Subnetmask for internal ipv4 vpn net
OPENVPN2_IPV4_PUSH_DHCP_DNS='9.9.9.9' # IPv4 DNS-Server
OPENVPN2_IPV4_PUSH_DHCP_WINS=''            # IPv4 WINS-Server
OPENVPN2_IPV4_PUSH_ROUTE_N='1'        # IPv4 routes to push
OPENVPN2_IPV4_PUSH_ROUTE_1_NET='192.168.0.0'      # ipv4 routes push to all clients
OPENVPN2_IPV4_PUSH_ROUTE_1_SUBNET='255.255.255.0' # ipv4 Network push to all clients
OPENVPN2_IPV6_NET='fd00:01b0:4210:bc01::/64'      # ipv6 Net push to all clients
OPENVPN2_IPV6_PUSH_ROUTE_N='0'        # IPv6 routes to push
OPENVPN2_IPV6_PUSH_ROUTE_1_NET=''
OPENVPN2_IPV6_PUSH_DHCP_DNS='2a03:b0c0:0000:1010:0000:0000:0de7:a001'

#CLIENTSETTING:
OPENVPN2_IPV4_MASQ='no'
OPENVPN2_IPV4_MASQ_IF=''
OPENVPN2_IPV6_MASQ='no'
OPENVPN2_IPV6_MASQ_IF=''

OPENVPN2_CLIENT_1_IPV4_LAN='yes' # use client ipv4 on lan site?
OPENVPN2_CLIENT_1_IPV4_WAN='yes' # use client ipv4 on wan site?
OPENVPN2_CLIENT_1_IPV6_LAN='no'  # use client ipv6 on lan site?
OPENVPN2_CLIENT_1_IPV6_WAN='no'  # use client ipv6 on wan site?
OPENVPN2_CLIENT_1_REDIRECT_IPV4='no' # redirect all ipv4 traffic into openvpn tunnel y/n
OPENVPN2_CLIENT_1_REDIRECT_IPV6='no' # redirect all ipv6 traffic into openvpn tunnel y/n
OPENVPN2_CLIENT_1_USE_LOCALPORT=''
OPENVPN2_CLIENT_1_USE_PROXY='no'
OPENVPN2_CLIENT_1_PROXY='http'
OPENVPN2_CLIENT_1_PROXY_AUTH='no'
OPENVPN2_CLIENT_1_PROXY_AUTH_TYPE='basic'
OPENVPN2_CLIENT_1_PROXY_AUTH_USERNAME=''
OPENVPN2_CLIENT_1_PROXY_AUTH_PASSWORD=''
OPENVPN2_CLIENT_1_ENABLE_LEGACY_DEFAULT='no'
OPENVPN2_CLIENT_1_ENABLE_SCRIPTSECURITY='0'
OPENVPN2_CLIENT_1_SCRIPT=''
OPENVPN2_CLIENT_1_IPV4_ROUTE=''  # ipv4 Net push to specified client
OPENVPN2_CLIENT_1_IPV4_NET=''
OPENVPN2_CLIENT_1_IPV4_ROUTE_DEST=''
OPENVPN2_CLIENT_1_IPV4_ROUTE_METRIC='1'
OPENVPN2_CLIENT_1_IPV6_ROUTE=''  # ipv6 Net push to specified client
OPENVPN2_CLIENT_1_IPV6_ROUTE_DEST=''
OPENVPN2_CLIENT_1_IPV6_ROUTE_METRIC='1'
#####################################################

read_old_variables ()
{
#Get Variables from old Configfile
    if [ -f $configfile ]
    then
      #mecho -info "Using previous configuration file"
      . $configfile
    fi
}

modify_variables ()
{
    ## Wenn bei einer alten konfiguration kleiner 1.0.1 OPENVPN2_ROUTE_N=0 dann hochziehen auf 1
    if [ -f /tmp/oldovpn ]
    then
        if [ "$OPENVPN2_ROUTE_N" = "0" ]
        then
            . /etc/config.d/base
            OPENVPN2_ROUTE_N=1
            OPENVPN2_ROUTE_1_NET=$IP_ETH_1_NETWORK
            OPENVPN2_ROUTE_1_SUBNET=$IP_ETH_1_NETMASK
        fi
        rm -f /tmp/oldovpn
    fi

    idx=1
    idxs=1
    idxs=1
    while [ "$idx" -le "$OPENVPN2_CLIENT_N" ]
    do
        ### IPv6
        eval clientv6='$OPENVPN2_CLIENT_'$idx'_IPV6'
        if [ "$clientv6" = "" ]
        then
            eval 'OPENVPN2_CLIENT_'$idx'_IPV6'=no
        elif [ "$clientv6" = "no" ]
        then
            eval 'OPENVPN2_CLIENT_'$idx'_IPV6'=no
        elif [ "$clientv6" = "yes" ]
        then
            eval 'OPENVPN2_CLIENT_'$idx'_IPV6'=yes
        fi
        ### Clienttyp
        eval clienttype='OPENVPN2_CLIENT_'$idx'_TYPE'
        if [ "$clienttype" = "win32" ]
        then
            eval 'OPENVPN2_CLIENT_'$idx'_TYPE'=windows
        elif [ "$clienttype" = "win" ]
        then
            eval 'OPENVPN2_CLIENT_'$idx'_TYPE'=windows
        elif [ "$clienttype" = "" ]
        then
            eval 'OPENVPN2_CLIENT_'$idx'_TYPE'=windows
        fi
        eval redv4='$OPENVPN2_CLIENT_'$idx'_REDIRECT'
        if [ "$redv4" = "" ]
        then
            redv4=no
        fi
        eval cwan6='$OPENVPN2_CLIENT_'$idx'_IPV6'
        eval 'OPENVPN2_CLIENT_'$idx'_REDIRECT_IPV4'=$redv4
        eval 'OPENVPN2_CLIENT_'$idx'_IPV6_WAN'=$cwan6
        ### Ende
        idx=`/usr/bin/expr $idx + 1`
    done

    ##Deprecated option
    ##Wenn  OPENVPN2_SERVER_CERT noch nicht im Configfile dann alte Version von
    ##installiert. Deshalb muss remote-cert-tls gesetzt werden.
    if [ -f $configfile ]
    then
        if ! grep -q ^OPENVPN2_SERVER_CERT $configfile
        then
            OPENVPN2_SERVER_CERT='remote-cert-tls'
        else
            OPENVPN2_SERVER_CERT=$OPENVPN2_SERVER_CERT
        fi
        if [ "$OPENVPN2_SERVER_CERT" = "" ]
        then
            OPENVPN2_SERVER_CERT=remote-cert-tls
        fi
    fi

    #### Umbau Paketversion 1.0.15
    if [ -f $configfile ]
    then
        . $configfile
        if ! grep -q ^OPENVPN2_SERVER_ENABLE_IPV6_WAN $configfile
        then
            OPENVPN2_SERVER_ENABLE_IPV6_WAN=$OPENVPN2_SERVER_USE_IPV6
        fi
         if ! grep -q ^OPENVPN2_IPV4_NET $configfile
        then
            OPENVPN2_IPV4_NET=$OPENVPN2_NET
        fi
        if ! grep -q ^OPENVPN2_IPV4_SUBNET $configfile
        then
            OPENVPN2_IPV4_SUBNET=$OPENVPN2_SUBNET
        fi
        if ! grep -q ^OPENVPN2_IPV4_PUSH_DHCP_DNS $configfile
        then
            OPENVPN2_IPV4_PUSH_DHCP_DNS=$OPENVPN2_DHCP_DNS
        fi
        if ! grep -q ^OPENVPN2_IPV4_MASQ $configfile
        then
            OPENVPN2_IPV4_MASQ=$OPENVPN2_MASQ
        fi
        if ! grep -q ^OPENVPN2_IPV4_MASQ_IF $configfile
        then
            OPENVPN2_IPV4_MASQ_IF=$OPENVPN2_MASQ_IF
        fi
        if ! grep -q ^OPENVPN2_IPV4_PUSH_ROUTE_N $configfile
        then
            OPENVPN2_IPV4_PUSH_ROUTE_N=$OPENVPN2_ROUTE_N
        fi
        if ! grep -q ^OPENVPN2_IPV4_PUSH_DHCP_WINS $configfile
        then
            OPENVPN2_IPV4_PUSH_DHCP_WINS=$OPENVPN2_DHCP_WINS
        fi

        if ! grep -q ^OPENVPN2_IPV4_PUSH_ROUTE_N $configfile
        then
            OPENVPN2_IPV4_PUSH_ROUTE_N=$OPENVPN2_ROUTE_N
            while [ "$idxs" -le "$OPENVPN2_IPV4_PUSH_ROUTE_N" ]
            do
                eval net4='$OPENVPN2_ROUTE_'$idxs'_NET'
                eval sub4='$OPENVPN2_ROUTE_'$idxs'_SUBNET'
                eval 'OPENVPN2_IPV4_PUSH_ROUTE_'$idxs'_NET'=$net4
                eval 'OPENVPN2_IPV4_PUSH_ROUTE_'$idxs'_SUBNET'=$sub4
                idxs=`/usr/bin/expr $idxs + 1`
            done
        fi
    fi
}

make_config_file()
{
 internal_conf_file=${1}
 (

 #--------------------------------------------------------------------------------
 printgpl -conf ${package_name} `date --rfc-3339=date` "OJae" "Olaf Jaehrling eisfair(at)ojaehrling(dot)de"
 #--------------------------------------------------------------------------------

  #-----------------------------------------------------------------------------
  printgroup "General settings "
  #-----------------------------------------------------------------------------
  printvar "START_OPENVPN2"             "Start openvpn at boottime"
  printvar "OPENVPN2_SERVER_ACTIVE"     "Activate OpenVPN-Server"
  printvar "OPENVPN2_CHECK_FOR_NEW_VERSION" "check for new openvpn2 version via cronjob? yes/no"
  printvar "OPENVPN2_HOSTNAME"          "FQDN to contact from extern"
  printvar "OPENVPN2_SERVER_CERT"       "use remote-cert-tls or ns-cert-type"
  printvar "OPENVPN2_SERVER_CERT_HASH"  "select hash"
  printvar "OPENVPN2_SERVER_ENABLE_FLOAT" "enable flaoting?"
  printvar "OPENVPN2_SERVER_ENABLE_MSSFIX" "MTU-size if needed"
  printvar "OPENVPN2_SERVER_ENABLE_LEGACY_DEFAULT" "enable provider legacy default"
  printvar "OPENVPN2_HMAC_AUTH"         "use HMAC Auth"
  printvar "OPENVPN2_COMPRESSION"       "enable compression?"
  printvar "OPENVPN2_PORT"              "Port to listen for incoming connections"
  printvar "OPENVPN2_PROTOCOL"          "udp or tcp"
  printvar "OPENVPN2_CIPHER"            "cipher algorithms to use"
  printvar "OPENVPN2_SERVER_IF_TYPE"    "tun or tap"
  printvar "OPENVPN2_SERVER_ENABLE_IPV6_LAN" "enable ipv6 for server on lan site"
  printvar "OPENVPN2_SERVER_ENABLE_IPV4_WAN" "enable ipv4 for server on wan site"
  printvar "OPENVPN2_SERVER_ENABLE_IPV6_WAN" "enable ipv6 for server on wan site"

  #-----------------------------------------------------------------------------
  printgroup "Server settings"
  #-----------------------------------------------------------------------------

  printvar "OPENVPN2_IPV4_NET"                 "Net for internal ipv4 vpn net"
  printvar "OPENVPN2_IPV4_SUBNET"              "Subnetmask for internal ipv4 vpn net"
  printvar "OPENVPN2_IPV4_PUSH_DHCP_DNS"            "IPv4 DNS-Server"
  printvar "OPENVPN2_IPV4_PUSH_DHCP_WINS"           "IPv4 WINS-Server"
  printvar "OPENVPN2_IPV6_NET"                 "ipv6 Net push to all clients"
  printvar "OPENVPN2_IPV6_PUSH_DHCP_DNS"       "ipv6 dns server"
  printvar "OPENVPN2_DHCP_DOMAIN"       "Domainname"
  printvar "OPENVPN2_IPV4_PUSH_ROUTE_N"        "IPv4 routes to push"
  idx=1
  while [ "$idx" -le "$OPENVPN2_IPV4_PUSH_ROUTE_N" ]
  do
      printvar 'OPENVPN2_IPV4_PUSH_ROUTE_'$idx'_NET'    "ipv4 routes push to all clients"
      printvar 'OPENVPN2_IPV4_PUSH_ROUTE_'$idx'_SUBNET' "ipv4 Network push to all clients"
      echo
      idx=`/usr/bin/expr $idx + 1`
  done
  printvar "OPENVPN2_IPV6_PUSH_ROUTE_N"        "IPv6 routes to push"
  idx=1
  while [ "$idx" -le "$OPENVPN2_IPV6_PUSH_ROUTE_N" ]
  do
      printvar 'OPENVPN2_IPV6_PUSH_ROUTE_'$idx'_NET'    "ipv6 routes push to all clients"
      echo
      idx=`/usr/bin/expr $idx + 1`
  done

  printvar "OPENVPN2_IPV4_MASQ"              "Masquerade clients"
  printvar "OPENVPN2_IPV4_MASQ_IF"           "Interface for Masquerade"
  printvar "OPENVPN2_IPV6_MASQ"              "Masquerade clients"
  printvar "OPENVPN2_IPV6_MASQ_IF"           "Interface for Masquerade"
  printvar "OPENVPN2_APPEND_LOG"        "erweitertes Log einschalten"
  printvar "OPENVPN2_CLIENT_TO_CLIENT"  "allow client to client communication?"

  #-----------------------------------------------------------------------------
  printgroup "Client only settings"
  #-----------------------------------------------------------------------------

  printvar "OPENVPN2_CLIENT_ONLY_MODE"  "yes/no"
  printvar "OPENVPN2_CLIENT_ONLY_REMOTE_SERVER"  "Domain-name or ip from remorte vpn server"
  printvar "OPENVPN2_CLIENT_ONLY_NAME"  "Common Name of Client"
  printvar "OPENVPN2_CLIENT_ONLY_PORT"  "Port to remote connections "
  printvar "OPENVPN2_CLIENT_ONLY_IF_TYPE"   "tun or tap"
  printvar "OPENVPN2_CLIENT_ONLY_PROTOCOL"  "udp or tcp"
  printvar "OPENVPN2_CLIENT_ONLY_CIPHER"  "cipher algorithms to use "
  printvar "OPENVPN2_CLIENT_ONLY_COMPRESSION"  "enable compression?"
  printvar "OPENVPN2_CLIENT_ONLY_HMAC_AUTH"  "use HMAC Auth"
  printvar "OPENVPN2_CLIENT_ONLY_CA_OR_PKCS12" "use pkcs12 or pem-file"
  printvar "OPENVPN2_CLIENT_ONLY_CA_OR_PKCS12_FILE" "path to your pkcs12 or pem file"
  printvar "OPENVPN2_CLIENT_ONLY_AUTH_USER_PASS_FILE" "Auth-Password-File"
  printvar "OPENVPN2_CLIENT_ONLY_AUTH_USER_PASSWORD" "Enter then Authpassword"
  printvar "OPENVPN2_CLIENT_ONLY_VERIFY_X509_NAME" "509 Name"
  printvar "OPENVPN2_CLIENT_ONLY_CERT"       "use remote-cert-tls or ns-cert-type"
  printvar "OPENVPN2_CLIENT_ONLY_IPV4_LAN"  "use client ipv4 on lan site? "
  printvar "OPENVPN2_CLIENT_ONLY_IPV4_WAN"  "use client ipv4 on wan site? "
  printvar "OPENVPN2_CLIENT_ONLY_IPV6_LAN"  "use client ipv6 on lan site? "
  printvar "OPENVPN2_CLIENT_ONLY_IPV6_WAN"  "use client ipv6 on wan site? "
  printvar "OPENVPN2_CLIENT_ONLY_REDIRECT_IPV4"  "redirect all ipv4 traffic into openvpn tunnel y/n "
  printvar "OPENVPN2_CLIENT_ONLY_REDIRECT_IPV6"  "redirect all ipv6 traffic into openvpn tunnel y/n "
  printvar "OPENVPN2_CLIENT_ONLY_USE_LOCALPORT"  "do you must use a specified local port? port number? "
  printvar "OPENVPN2_CLIENT_ONLY_USE_PROXY"  "use a proxy? "
  printvar "OPENVPN2_CLIENT_ONLY_PROXY"  "http or socks5 proxy? "
  printvar "OPENVPN2_CLIENT_ONLY_PROXY_AUTH"  "need authoristation? "
  printvar "OPENVPN2_CLIENT_ONLY_PROXY_AUTH_TYPE"  "ntlm or basic? "
  printvar "OPENVPN2_CLIENT_ONLY_PROXY_AUTH_USERNAME"  "proxy username "
  printvar "OPENVPN2_CLIENT_ONLY_PROXY_AUTH_PASSWORD"  "proxy password "
  printvar "OPENVPN2_CLIENT_ONLY_ENABLE_LEGACY_DEFAULT" "enable provider legacy default"
  printvar "OPENVPN2_CLIENT_ONLY_ENABLE_SCRIPTSECURITY"  "enable scriptsecurity 1,2 or 3? Number? "
  printvar "OPENVPN2_CLIENT_ONLY_SCRIPT"  "remote script to exucute if tunnel esablished "
  printvar "OPENVPN2_CLIENT_ONLY_IPV4_ROUTE"  "ipv4 Net enable only on specified client "
  printvar "OPENVPN2_CLIENT_ONLY_IPV4_NET"  "ipv4 Netmask enable only on specified client "
  printvar "OPENVPN2_CLIENT_ONLY_IPV4_ROUTE_DEST"  "ipv4 route destination "
  printvar "OPENVPN2_CLIENT_ONLY_IPV4_ROUTE_METRIC"  "ipv4 route metric "
  printvar "OPENVPN2_CLIENT_ONLY_IPV6_ROUTE"  "ipv6 Net enable only on specified client "
  printvar "OPENVPN2_CLIENT_ONLY_IPV6_ROUTE_DEST"  "ipv6 route destination "
  printvar "OPENVPN2_CLIENT_ONLY_IPV6_ROUTE_METRIC"  "ipv6 route metric "

  #-----------------------------------------------------------------------------
  printgroup "Client settings"
  #-----------------------------------------------------------------------------
  printvar "OPENVPN2_CLIENT_N"          "No of OpenVPN-Clients"
  idx=1
  while [ "$idx" -le "$OPENVPN2_CLIENT_N" ]
  do
    printvar 'OPENVPN2_CLIENT_'$idx'_ACTIVE' "Can Client connect to server"
    printvar 'OPENVPN2_CLIENT_'$idx'_NAME'   "Common Name of Client"
    printvar 'OPENVPN2_CLIENT_'$idx'_TYPE'   "windows, linux or mac"
    printvar 'OPENVPN2_CLIENT_'$idx'_IPV4_LAN' "use client ipv4 on lan site?"
    printvar 'OPENVPN2_CLIENT_'$idx'_IPV4_WAN' "use client ipv4 on wan site?"
    printvar 'OPENVPN2_CLIENT_'$idx'_IPV6_LAN' "use client ipv6 on lan site?"
    printvar 'OPENVPN2_CLIENT_'$idx'_IPV6_WAN' "use client ipv6 on wan site?"
    printvar 'OPENVPN2_CLIENT_'$idx'_REDIRECT_IPV4' "redirect all ipv4 traffic into openvpn tunnel y/n"
    printvar 'OPENVPN2_CLIENT_'$idx'_REDIRECT_IPV6' "redirect all ipv6 traffic into openvpn tunnel y/n"
    printvar 'OPENVPN2_CLIENT_'$idx'_USE_LOCALPORT' "do you must use a specified local port? port number?"
    printvar 'OPENVPN2_CLIENT_'$idx'_USE_PROXY' "use a proxy?"
    printvar 'OPENVPN2_CLIENT_'$idx'_PROXY' "http or socks5 proxy?"
    printvar 'OPENVPN2_CLIENT_'$idx'_PROXY_AUTH' "need authoristation?"
    printvar 'OPENVPN2_CLIENT_'$idx'_PROXY_AUTH_TYPE' "ntlm or basic?"
    printvar 'OPENVPN2_CLIENT_'$idx'_PROXY_AUTH_USERNAME' "proxy username"
    printvar 'OPENVPN2_CLIENT_'$idx'_PROXY_AUTH_PASSWORD' "proxy password"
    printvar 'OPENVPN2_CLIENT_'$idx'_ENABLE_LEGACY_DEFAULT' "enable provider legacy default"
    printvar 'OPENVPN2_CLIENT_'$idx'_ENABLE_SCRIPTSECURITY' "enable scriptsecurity 1,2 or 3? Number?"
    printvar 'OPENVPN2_CLIENT_'$idx'_SCRIPT' "remote script to exucute if tunnel esablished"
    printvar 'OPENVPN2_CLIENT_'$idx'_IPV4_ROUTE' "ipv4 Net enable only on specified client"
    printvar 'OPENVPN2_CLIENT_'$idx'_IPV4_NET' "ipv4 Netmask enable only on specified client"
    printvar 'OPENVPN2_CLIENT_'$idx'_IPV4_ROUTE_DEST' "ipv4 route destination"
    printvar 'OPENVPN2_CLIENT_'$idx'_IPV4_ROUTE_METRIC' "ipv4 route metric"
    printvar 'OPENVPN2_CLIENT_'$idx'_IPV6_ROUTE' "ipv6 Net enable only on specified client"
    printvar 'OPENVPN2_CLIENT_'$idx'_IPV6_ROUTE_DEST' "ipv6 route destination"
    printvar 'OPENVPN2_CLIENT_'$idx'_IPV6_ROUTE_METRIC' "ipv6 route metric"
    idx=`/usr/bin/expr $idx + 1`
  done
  #-----------------------------------------------------------------------------
  printgroup "Easy-RSA settings"
  #-----------------------------------------------------------------------------
  printvar "OPENVPN2_COUNTRY"           "i.e. DE,US"
  printvar "OPENVPN2_PROVINCE"          "i.e. NRW,Hessen"
  printvar "OPENVPN2_CITY"              "i.e. Koeln,Frankfurt"
  printvar "OPENVPN2_ORG"               "i.e. privat, Companyname"
  printvar "OPENVPN2_EMAIL"             "i.e. openvpn@company.com"
  printvar "OPENVPN2_EXPORTDIR"         "Exportdirectory"
  #------------------------------------------------------------------------------
  printgroup "Brute Force Blocking Check new Version "
  #--------------------------------------------------------------------------------
  printvar "OPENVPN2_CHECK_NEW_VERSION_CRON" "cronjob for new versionscheck"
  printvar "OPENVPN2_CHECK_NEW_VERSION_TO_ADDRESS" "email address to send information about new Version"
  printvar "OPENVPN2_CHECK_NEW_VERSION_FROM_ADDRESS" "sender email address for new version"
  #------------------------------------------------------------------------------
  printend
  #-----------------------------------------------------------------------------
 ) > ${internal_conf_file}
 # Set rights
 chmod 0600 ${internal_conf_file}
 chown root ${internal_conf_file}

}


### -------------------------------------------------------------------------
### Create the check.d file
### -------------------------------------------------------------------------

make_check_file()
{
#--------------------------------------------------------------------------------
printgpl -check ${package_name} ${DATUM} "OJae" "Olaf Jaehrling <eisfair[at]ojaehrling[dot]de>" >/etc/check.d/${package}
#--------------------------------------------------------------------------------
cat >>/etc/check.d/${package} <<EOF
# Variable OPT_VARIABLE VARIABLE_N VALUE
START_OPENVPN2                          -                                -                                YESNO
OPENVPN2_SERVER_ACTIVE                      START_OPENVPN2                   -                            YESNO
OPENVPN2_HOSTNAME                           OPENVPN2_SERVER_ACTIVE           -                            FQDN
OPENVPN2_CHECK_FOR_NEW_VERSION              START_OPENVPN2                   -                            YESNO
OPENVPN2_CHECK_NEW_VERSION_CRON             OPENVPN2_CHECK_FOR_NEW_VERSION   -                            CRONTAB
OPENVPN2_CHECK_NEW_VERSION_TO_ADDRESS       OPENVPN2_CHECK_FOR_NEW_VERSION   -                            OVPNMAILADDR
OPENVPN2_CHECK_NEW_VERSION_FROM_ADDRESS     OPENVPN2_CHECK_FOR_NEW_VERSION   -                            OVPNMAILADDR
OPENVPN2_SERVER_CERT                        OPENVPN2_SERVER_ACTIVE           -                            OVPN_CERT_CUI
OPENVPN2_SERVER_CERT_HASH                   OPENVPN2_SERVER_ACTIVE               -                        OVPN_CERT_HASH_CUI
OPENVPN2_SERVER_ENABLE_FLOAT                OPENVPN2_SERVER_ACTIVE           -                            YESNO
OPENVPN2_SERVER_ENABLE_MSSFIX               OPENVPN2_SERVER_ACTIVE           -                            ENUMERIC
OPENVPN2_SERVER_ENABLE_LEGACY_DEFAULT       OPENVPN2_SERVER_ACTIVE           -                            YESNO
OPENVPN2_SERVER_IF_TYPE                     OPENVPN2_SERVER_ACTIVE           -                            OVPN_TUN_CUI
OPENVPN2_SERVER_ENABLE_IPV6_LAN             OPENVPN2_SERVER_ACTIVE           -                            YESNO
OPENVPN2_SERVER_ENABLE_IPV4_WAN             OPENVPN2_SERVER_ACTIVE           -                            YESNO
OPENVPN2_SERVER_ENABLE_IPV6_WAN             OPENVPN2_SERVER_ACTIVE           -                            YESNO
OPENVPN2_IPV4_NET                           OPENVPN2_SERVER_ACTIVE           -                            IPADDR
OPENVPN2_IPV4_SUBNET                        OPENVPN2_SERVER_ACTIVE           -                            IPADDR
OPENVPN2_IPV4_PUSH_DHCP_DNS                 OPENVPN2_SERVER_ACTIVE           -                            EIPADDR
OPENVPN2_IPV4_PUSH_DHCP_WINS                OPENVPN2_SERVER_ACTIVE           -                            EIPADDR
OPENVPN2_IPV4_PUSH_ROUTE_N                  OPENVPN2_SERVER_ACTIVE           -                            NUMERIC
OPENVPN2_IPV4_PUSH_ROUTE_%_NET              OPENVPN2_SERVER_ACTIVE          OPENVPN2_IPV4_PUSH_ROUTE_N    IPADDR
OPENVPN2_IPV4_PUSH_ROUTE_%_SUBNET           OPENVPN2_SERVER_ACTIVE          OPENVPN2_IPV4_PUSH_ROUTE_N    IPADDR
OPENVPN2_IPV6_NET                           OPENVPN2_SERVER_ENABLE_IPV6_LAN  -                            OVPN_IP6NET
OPENVPN2_IPV6_PUSH_ROUTE_N                  OPENVPN2_SERVER_ENABLE_IPV6_LAN  -                            NUMERIC
OPENVPN2_IPV6_PUSH_ROUTE_%_NET              OPENVPN2_SERVER_ENABLE_IPV6_LAN OPENVPN2_IPV6_PUSH_ROUTE_N    OVPN_IP6ROUTE
OPENVPN2_IPV6_PUSH_DHCP_DNS                 OPENVPN2_SERVER_ENABLE_IPV6_LAN  -                            OVPN_IP6ADDR
OPENVPN2_IPV4_MASQ                          OPENVPN2_SERVER_ACTIVE           -                            YESNO
OPENVPN2_IPV4_MASQ_IF                       OPENVPN2_IPV4_MASQ               -                            OVPN_INTERFACE_CUI
OPENVPN2_IPV6_MASQ                          OPENVPN2_SERVER_ENABLE_IPV6_LAN  -                            YESNO
OPENVPN2_IPV6_MASQ_IF                       OPENVPN2_IPV6_MASQ               -                            OVPN_INTERFACE_CUI
OPENVPN2_PORT                               OPENVPN2_SERVER_ACTIVE           -                            PORT
OPENVPN2_CIPHER                             OPENVPN2_SERVER_ACTIVE           -                            OVPNCIPHER_CUI
OPENVPN2_HMAC_AUTH                          OPENVPN2_SERVER_ACTIVE           -                            OVPN_AUTH_CUI
OPENVPN2_COMPRESSION                        OPENVPN2_SERVER_ACTIVE           -                            OVPN_COMP_CUI
OPENVPN2_PROTOCOL                           OPENVPN2_SERVER_ACTIVE           -                            RE:udp|tcp
OPENVPN2_DHCP_DOMAIN                        OPENVPN2_SERVER_ACTIVE           -                            EDOMAIN
OPENVPN2_APPEND_LOG                         OPENVPN2_SERVER_ACTIVE           -                            YESNO
OPENVPN2_CLIENT_N                           START_OPENVPN2                   -                            NUMERIC
OPENVPN2_CLIENT_%_ACTIVE                    START_OPENVPN2                  OPENVPN2_CLIENT_N             YESNO
OPENVPN2_CLIENT_%_NAME                      OPENVPN2_CLIENT_%_ACTIVE        OPENVPN2_CLIENT_N             NONE
OPENVPN2_CLIENT_%_IPV4_LAN                  OPENVPN2_CLIENT_%_ACTIVE        OPENVPN2_CLIENT_N             YESNO
OPENVPN2_CLIENT_%_IPV4_WAN                  OPENVPN2_CLIENT_%_ACTIVE        OPENVPN2_CLIENT_N             YESNO
OPENVPN2_CLIENT_%_IPV6_LAN                  OPENVPN2_CLIENT_%_ACTIVE        OPENVPN2_CLIENT_N             YESNO
OPENVPN2_CLIENT_%_IPV6_WAN                  OPENVPN2_CLIENT_%_ACTIVE        OPENVPN2_CLIENT_N             YESNO
OPENVPN2_CLIENT_%_REDIRECT_IPV4             OPENVPN2_CLIENT_%_IPV4_LAN      OPENVPN2_CLIENT_N             YESNO
OPENVPN2_CLIENT_%_REDIRECT_IPV6             OPENVPN2_CLIENT_%_IPV6_LAN      OPENVPN2_CLIENT_N             YESNO
OPENVPN2_CLIENT_%_TYPE                      OPENVPN2_CLIENT_%_REDIRECT_IPV4 OPENVPN2_CLIENT_N             OVPN_CLIENTSYS_CUI
OPENVPN2_CLIENT_%_USE_LOCALPORT             OPENVPN2_CLIENT_%_ACTIVE        OPENVPN2_CLIENT_N             ENUMERIC
OPENVPN2_CLIENT_%_USE_PROXY                 OPENVPN2_CLIENT_%_ACTIVE        OPENVPN2_CLIENT_N             YESNO
OPENVPN2_CLIENT_%_PROXY                     OPENVPN2_CLIENT_%_USE_PROXY     OPENVPN2_CLIENT_N             RE:http|socks
OPENVPN2_CLIENT_%_PROXY_AUTH                OPENVPN2_CLIENT_%_ACTIVE        OPENVPN2_CLIENT_N             YESNO
OPENVPN2_CLIENT_%_PROXY_AUTH_TYPE           OPENVPN2_CLIENT_%_PROXY_AUTH    OPENVPN2_CLIENT_N             RE:ntlm|basic
OPENVPN2_CLIENT_%_PROXY_AUTH_USERNAME       OPENVPN2_CLIENT_%_PROXY_AUTH    OPENVPN2_CLIENT_N             NONE
OPENVPN2_CLIENT_%_PROXY_AUTH_PASSWORD       OPENVPN2_CLIENT_%_PROXY_AUTH    OPENVPN2_CLIENT_N             NONE
OPENVPN2_CLIENT_%_ENABLE_LEGACY_DEFAULT     OPENVPN2_CLIENT_%_ACTIVE        OPENVPN2_CLIENT_N             YESNO
OPENVPN2_CLIENT_%_ENABLE_SCRIPTSECURITY     OPENVPN2_CLIENT_%_ACTIVE        OPENVPN2_CLIENT_N             RE:0|1|2|3
OPENVPN2_CLIENT_%_SCRIPT                    OPENVPN2_CLIENT_%_ACTIVE        OPENVPN2_CLIENT_N             E_ABS_PATH
OPENVPN2_CLIENT_%_IPV4_ROUTE                OPENVPN2_CLIENT_%_IPV4_LAN      OPENVPN2_CLIENT_N             EIPADDR
OPENVPN2_CLIENT_%_IPV4_NET                  OPENVPN2_CLIENT_%_IPV4_LAN      OPENVPN2_CLIENT_N             EIPADDR
OPENVPN2_CLIENT_%_IPV4_ROUTE_DEST           OPENVPN2_CLIENT_%_IPV4_LAN      OPENVPN2_CLIENT_N             EIPADDR
OPENVPN2_CLIENT_%_IPV4_ROUTE_METRIC         OPENVPN2_CLIENT_%_IPV4_LAN      OPENVPN2_CLIENT_N             ENUMERIC
OPENVPN2_CLIENT_%_IPV6_ROUTE                OPENVPN2_CLIENT_%_IPV6_LAN      OPENVPN2_CLIENT_N             OVPN_IP6NET
OPENVPN2_CLIENT_%_IPV6_ROUTE_DEST           OPENVPN2_CLIENT_%_IPV6_LAN      OPENVPN2_CLIENT_N             OVPN_IP6ADDR
OPENVPN2_CLIENT_%_IPV6_ROUTE_METRIC         OPENVPN2_CLIENT_%_IPV6_LAN      OPENVPN2_CLIENT_N             NUMERIC
OPENVPN2_CLIENT_ONLY_MODE                   START_OPENVPN2                           -                    YESNO
OPENVPN2_CLIENT_ONLY_REMOTE_SERVER          OPENVPN2_CLIENT_ONLY_MODE                -                    EDOMAIN
OPENVPN2_CLIENT_ONLY_NAME                   OPENVPN2_CLIENT_ONLY_MODE                -                    NONE
OPENVPN2_CLIENT_ONLY_PORT                   OPENVPN2_CLIENT_ONLY_MODE                -                    NUMERIC
OPENVPN2_CLIENT_ONLY_PROTOCOL               OPENVPN2_CLIENT_ONLY_MODE                -                    RE:udp|tcp
OPENVPN2_CLIENT_ONLY_IF_TYPE                OPENVPN2_CLIENT_ONLY_MODE                -                    OVPN_TUN_CUI
OPENVPN2_CLIENT_ONLY_CIPHER                 OPENVPN2_CLIENT_ONLY_MODE                -                    OVPNCIPHER_CUI
OPENVPN2_CLIENT_ONLY_COMPRESSION            OPENVPN2_CLIENT_ONLY_MODE                -                    OVPN_COMP_CUI
OPENVPN2_CLIENT_ONLY_HMAC_AUTH              OPENVPN2_CLIENT_ONLY_MODE                -                    OVPN_AUTH_CUI
OPENVPN2_CLIENT_ONLY_AUTH_USER_PASS_FILE    OPENVPN2_CLIENT_ONLY_MODE                -                    E_ABS_PATH
OPENVPN2_CLIENT_ONLY_AUTH_USER_PASSWORD     OPENVPN2_CLIENT_ONLY_MODE                -                    NONE
OPENVPN2_CLIENT_ONLY_VERIFY_X509_NAME       OPENVPN2_CLIENT_ONLY_MODE                -                    NONE
OPENVPN2_CLIENT_ONLY_CA_OR_PKCS12           OPENVPN2_CLIENT_ONLY_MODE                -                    RE:pkcs12|ca
OPENVPN2_CLIENT_ONLY_CA_OR_PKCS12_FILE      OPENVPN2_CLIENT_ONLY_MODE                -                    ABS_PATH
OPENVPN2_CLIENT_ONLY_CERT                   OPENVPN2_CLIENT_ONLY_MODE                -                    OVPN_CERT_CUI2
OPENVPN2_CLIENT_ONLY_IPV4_LAN               OPENVPN2_CLIENT_ONLY_MODE                -                    YESNO
OPENVPN2_CLIENT_ONLY_IPV4_WAN               OPENVPN2_CLIENT_ONLY_MODE                -                    YESNO
OPENVPN2_CLIENT_ONLY_IPV6_LAN               OPENVPN2_CLIENT_ONLY_MODE                -                    YESNO
OPENVPN2_CLIENT_ONLY_IPV6_WAN               OPENVPN2_CLIENT_ONLY_MODE                -                    YESNO
OPENVPN2_CLIENT_ONLY_REDIRECT_IPV4          OPENVPN2_CLIENT_ONLY_IPV4_LAN            -                    YESNO
OPENVPN2_CLIENT_ONLY_REDIRECT_IPV6          OPENVPN2_CLIENT_ONLY_IPV6_LAN            -                    YESNO
OPENVPN2_CLIENT_ONLY_USE_LOCALPORT          OPENVPN2_CLIENT_ONLY_MODE                -                    ENUMERIC
OPENVPN2_CLIENT_ONLY_USE_PROXY              OPENVPN2_CLIENT_ONLY_MODE                -                    YESNO
OPENVPN2_CLIENT_ONLY_PROXY                  OPENVPN2_CLIENT_ONLY_USE_PROXY           -                    RE:http|socks
OPENVPN2_CLIENT_ONLY_PROXY_AUTH             OPENVPN2_CLIENT_ONLY_USE_PROXY           -                    YESNO
OPENVPN2_CLIENT_ONLY_PROXY_AUTH_TYPE        OPENVPN2_CLIENT_ONLY_PROXY_AUTH          -                    RE:ntlm|basic
OPENVPN2_CLIENT_ONLY_PROXY_AUTH_USERNAME    OPENVPN2_CLIENT_ONLY_PROXY_AUTH          -                    NONE
OPENVPN2_CLIENT_ONLY_PROXY_AUTH_PASSWORD    OPENVPN2_CLIENT_ONLY_PROXY_AUTH          -                    NONE
OPENVPN2_CLIENT_ONLY_ENABLE_LEGACY_DEFAULT  OPENVPN2_CLIENT_ONLY_MODE                -                    YESNO
OPENVPN2_CLIENT_ONLY_ENABLE_SCRIPTSECURITY  OPENVPN2_CLIENT_ONLY_MODE                -                    RE:0|1|2|3
OPENVPN2_CLIENT_ONLY_SCRIPT                 OPENVPN2_CLIENT_ONLY_MODE                -                    E_ABS_PATH
OPENVPN2_CLIENT_ONLY_IPV4_ROUTE             OPENVPN2_CLIENT_ONLY_IPV4_LAN            -                    EIPADDR
OPENVPN2_CLIENT_ONLY_IPV4_NET               OPENVPN2_CLIENT_ONLY_IPV4_LAN            -                    EIPADDR
OPENVPN2_CLIENT_ONLY_IPV4_ROUTE_DEST        OPENVPN2_CLIENT_ONLY_IPV4_LAN            -                    EIPADDR
OPENVPN2_CLIENT_ONLY_IPV4_ROUTE_METRIC      OPENVPN2_CLIENT_ONLY_IPV4_LAN            -                    ENUMERIC
OPENVPN2_CLIENT_ONLY_IPV6_ROUTE             OPENVPN2_CLIENT_ONLY_IPV6_LAN            -                    OVPN_IP6NET
OPENVPN2_CLIENT_ONLY_IPV6_ROUTE_DEST        OPENVPN2_CLIENT_ONLY_IPV6_LAN            -                    OVPN_IP6ADDR
OPENVPN2_CLIENT_ONLY_IPV6_ROUTE_METRIC      OPENVPN2_CLIENT_ONLY_IPV6_LAN            -                    NUMERIC
OPENVPN2_CLIENT_TO_CLIENT                   OPENVPN2_SERVER_ACTIVE                   -                    YESNO
OPENVPN2_COUNTRY                            OPENVPN2_SERVER_ACTIVE                   -                    NOTEMPTY
OPENVPN2_PROVINCE                           OPENVPN2_SERVER_ACTIVE                   -                    NOTEMPTY
OPENVPN2_CITY                               OPENVPN2_SERVER_ACTIVE                   -                    NOTEMPTY
OPENVPN2_ORG                                OPENVPN2_SERVER_ACTIVE                   -                    NOTEMPTY
OPENVPN2_EMAIL                              OPENVPN2_SERVER_ACTIVE                   -                    MAILADDR
OPENVPN2_EXPORTDIR                          OPENVPN2_SERVER_ACTIVE                   -                    ABS_PATH

EOF

 # Set rights for check file
 chmod 0600 /etc/check.d/${package}
 chown root /etc/check.d/${package}
}

## -------------------------------------------------------------------------
### Create the exp file
### -------------------------------------------------------------------------
make_exp_file()
{
#--------------------------------------------------------------------------------
printgpl -check_exp ${package_name} ${DATUM} "OJae" "Olaf Jaehrling <eisfair[at]ojaehrling[dot]de>" >/etc/check.d/${package}.exp
#--------------------------------------------------------------------------------
cat >>/etc/check.d/${package}.exp <<EOF

OVPNCIPHER_CUI = 'BF-CBC|DES-CBC|RC2-CBC|DES-EDE-CBC|DES-EDE3-CBC|DESX-CBC|RC2-40-CBC|CAST5-CBC|RC2-64-CBC|AES-128-CBC|AES-192-CBC|AES-256-CBC|CAMELLIA-128-CBC|CAMELLIA-192-CBC|CAMELLIA-256-CBC|SEED-CBC' :'only BF-CBC|DES-CBC|RC2-CBC|DES-EDE-CBC|DES-EDE3-CBC|DESX-CBC|RC2-40-CBC|CAST5-CBC|RC2-64-CBC|AES-128-CBC|AES-192-CBC|AES-256-CBC|CAMELLIA-128-CBC|CAMELLIA-192-CBC|CAMELLIA-256-CBC|SEED-CBC are allowed'
OVPN_INTERFACE_CUI = '(RE:NOTEMPTY)' : 'please select a NIC'
OVPN_TUN_CUI = 'tun|tap|tun[0-9]|tap[0-9]' : 'please select tun|tap|tun[0-9]|tap[0-9]'
OVPN_CLIENTSYS_CUI = 'windows|linux|mac' : 'please select windows, linux or mac'
OVPN_CERT_CUI = 'remote-cert-tls|ns-cert-type' : 'remote-cert-tls or ns-cert-type'
OVPN_CERT_CUI2 = '()|remote-cert-tls|ns-cert-type' : 'blank,remote-cert-tls or ns-cert-type'
OVPN_IP6ADDR = '()|[[:xdigit:]][[:xdigit:]][[:xdigit:]][[:xdigit:]](:[[:xdigit:]][[:xdigit:]][[:xdigit:]][[:xdigit:]]){7}' : 'only complete ipv6 address with left-hand zeros but without mask like fd00:01b0:4210:bc01:0000:0000:0000:0001'
OVPN_IP6NET = '()|[[:alnum:]](:?:?[[:alnum:]])*+\::/(RE:NUMERIC)' : 'only ipv6 address with mask are allowed'
OVPN_IP6ROUTE = '()|(RE:OVPN_IP6NET)+([[:space:]])+(RE:OVPN_IP6ADDR)+([[:space:]])+(RE:NUMERIC)' : 'ipv6net space ipv6 destination metric like fd00:aaaa:aaaa:bbbb::/64 fd00:01b0:4210:bc01:0000:0000:0000:0001 254'
OVPN_COMP_CUI = '()|no|lzo|lz4' : 'only blank lzo or lz4 are allowed'
OVPN_AUTH_CUI = '()|none|SHA512|SHA384|SHA256' : 'only blank, none, SHA512, SHA384 or SHA256 are allowed'
OVPN_CERT_HASH_CUI = 'sha256|sha384|sha512' : 'select sha256 or sha384 or sha512'
OVPNMAILADDR = '[[:alpha:]i/~.-]+|((RE:MAILADDR))|(RE:MAILADDR)([[:space:]]+(RE:MAILADDR))*' : ' 1 or more eMailadresses, use e.g. "aaaa@bbbb.ccc", aaaa@bbbb.ccc dddd@bbbb.ccc or root'

EOF
 # Set rights for exp file
 chmod 0600 /etc/check.d/${package}.exp
 chown root /etc/check.d/${package}.exp
}

make_ext_file()
{
#--------------------------------------------------------------------------------
printgpl -check_ext ${package} `date --rfc-3339=date` "OJae" "Olaf Jaehrling <eisfair[at]ojaehrling[dot]de>" >/etc/check.d/${package}.ext
#--------------------------------------------------------------------------------
cat >>/etc/check.d/${package}.ext <<EOF

foreach i in openvpn2_client_n
do
    if (openvpn2_client_%_use_proxy[i] == "yes" && openvpn2_protocol == "udp")
    then
        error "only OPENVPN2_CLIENT_\${i}_USE_PROXYr yes and OPENVPN2_PROTOCOL tcp are allowed"
    fi
    if (openvpn2_client_%_ipv4_wan[i] == "no" && openvpn2_client_%_ipv6_wan[i] == "no")
    then
        error "OPENVPN2_CLIENT_\${i}_IPV4_WAN or OPENVPN2_CLIENT_\${i}_IPV6_WAN must set to yes"
    fi
    if (openvpn2_client_%_redirect_ipv4[i] == "yes" && openvpn2_ipv4_masq == "no")
    then
        error "OPENVPN2_CLIENT_\${i}_REDIRECT_IPV4 and OPENVPN2_IPV4_MASQ are meaningful"
    fi
    if (openvpn2_client_%_redirect_ipv6[i] == "yes" && openvpn2_ipv6_masq == "no")
    then
        error "OPENVPN2_CLIENT_\${i}_REDIRECT_IPV6 and OPENVPN2_IPV6_MASQ are meaningful"
    fi
done


EOF

 # Set rights for ext file
 chmod 0600 /etc/check.d/${package}.ext
 chown root /etc/check.d/${package}.ext
}

# update from old version
read_old_variables

# modify variables from old version
modify_variables

# write new config file
make_config_file /etc/config.d/${package}

# write default config file
OPENVPN2_CLIENT_N=1
OPENVPN2_IPV6_PUSH_ROUTE_N=1
make_config_file /etc/default.d/${package}

# write check.d file
make_check_file

# write *.exp file
make_exp_file

# write *.ext file
make_ext_file

if [ ! -d /usr/local/openvpn/keys ]
then
    mkdir /usr/local/openvpn/keys
    touch /usr/local/openvpn/keys/index.txt
fi
exit 0

