#!/bin/sh
#-------------------------------------------------------------------------------
# /var/install/config.d/openvpn2.sh - configuration generator script 
#
# Copyright (c) 2016-2023 Olaf Jaehrling <eisfair[at]ojaehrling.de>
#
# Creation:     19.01.2006  th
# Last Update:  13.11.2023 OJae
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#-------------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

package="openvpn2"
configfile="/etc/config.d/$package"
basefile="/etc/config.d/base"
clientsfile="/etc/openvpn/clients"
vars="/usr/local/openvpn/vars"
pgmname=$0
OPENVPN2_S__ERVER_IF_TYPE='tun'

if [ ! -f $clientsfile ]
then
    touch $clientsfile
fi

. $basefile
. $configfile

c1=$1

_proxy ()
{
  if [ "$client_proxy" = "yes" ]
  then
      if [ "$client_proxytype" = "http" ]
      then
          if [ "$client_proxyauth" = "yes" ]
          then
              echo -e "$client_proxyuser\r" >$client_proxyauthfile
              echo -e "$client_proxypass\r" >>$client_proxyauthfile
              echo -e "http-proxy $client_proxyip $client_proxyport $client_proxyauthfile $client_authtype\r"
          else
              echo -e "http-proxy $client_proxyip $client_proxyport\r"
          fi
      elif [ "$client_proxytype" = "socks" ]
      then
          echo -e "socks-proxy $client_proxyip $client_proxyport\r"
      fi
  fi
}

_client_only ()
{
      if [ "$OPENVPN2_CLIENT_ONLY_MODE" = "yes" ]
      then
          if [ "$OPENVPN2_CLIENT_ONLY_NAME" = "" ]
          then
              client_name=client
          else
              client_name=$OPENVPN2_CLIENT_ONLY_NAME
          fi
          mecho --info "create clientonly config file for $client_name"
          # erstmal pruefen, ob ipv4 bzw ipv6 benoetigt wird
          if [ "$OPENVPN2_CLIENT_ONLY_IPV4_WAN" = "yes" -o "$OPENVPN2_CLIENT_ONLY_IPV4_LAN" = "yes" ]
          then
              NET4='yes'
          fi
          if [ "$OPENVPN2_CLIENT_ONLY_IPV6_WAN" = "yes" -o "$OPENVPN2_CLIENT_ONLY_IPV6_LAN" = "yes" ]
          then
              NET6='yes'
          fi
          # Create client-config-file
          tmp_file=$(/usr/bin/mktemp -t .XXXXXXXXXXXXX)
          (
          echo -e "#OpenVPN Client conf\r"
          echo -e "client\r"
          )> $tmp_file
          cat $tmp_file >/etc/openvpn/$client_name.conf
          if [ "$OPENVPN2_CLIENT_ONLY_USE_LOCALPORT" != "" ]
          then
              echo -e "lport $OPENVPN2_CLIENT_ONLY_USE_LOCALPORT\r" >>/etc/openvpn/$client_name.conf
          fi
          if  [ "$OPENVPN2_CLIENT_ONLY_IPV6_WAN" = "yes" ]
          then
              (
              echo -e "<connection>\r"
              echo -e "remote $OPENVPN2_CLIENT_ONLY_REMOTE_SERVER $OPENVPN2_CLIENT_ONLY_PORT $OPENVPN2_CLIENT_ONLY_PROTOCOL"6"\r"
              _proxy
              echo -e "</connection>\r"
              )>>/etc/openvpn/$client_name.conf
          fi
          if  [ "$OPENVPN2_CLIENT_ONLY_IPV4_WAN" = "yes" ]
          then
              (
              echo -e "<connection>\r"
              echo -e "remote $OPENVPN2_CLIENT_ONLY_REMOTE_SERVER $OPENVPN2_CLIENT_ONLY_PORT $OPENVPN2_CLIENT_ONLY_PROTOCOL\r"
              _proxy
              echo -e "</connection>\r"
              )>>/etc/openvpn/$client_name.conf
          fi

          if  [ "$OPENVPN2_CLIENT_ONLY_AUTH_USER_PASS_FILE" != "" ]
          then
              PWPATH=`echo $OPENVPN2_CLIENT_ONLY_AUTH_USER_PASS_FILE| sed 's/\.[^.]*$/\//'`
              mkdir -p $PWPATH
              echo -e "askpass $OPENVPN2_CLIENT_ONLY_AUTH_USER_PASS_FILE\r" >>/etc/openvpn/$client_name.conf
              echo "$OPENVPN2_CLIENT_ONLY_AUTH_USER_PASSWORD" >$OPENVPN2_CLIENT_ONLY_AUTH_USER_PASS_FILE
          fi
          if  [ "$OPENVPN2_CLIENT_ONLY_VERIFY_X509_NAME" != "" ]
          then
              echo -e "verify-x509-name $OPENVPN2_CLIENT_ONLY_VERIFY_X509_NAME\r" >>/etc/openvpn/$client_name.conf
          fi
          if  [ "$OPENVPN2_CLIENT_ONLY_IPV6_WAN" = "yes" -o "$OPENVPN2_CLIENT_ONLY_IPV4_WAN" = "yes" ]
          then
              if [ "$OPENVPN2_CLIENT_ONLY_CA_OR_PKCS12" = "pkcs12" ]
              then
                  echo -e "pkcs12 $OPENVPN2_CLIENT_ONLY_CA_OR_PKCS12_FILE\r" >>/etc/openvpn/$client_name.conf
              elif [ "$OPENVPN2_CLIENT_ONLY_CA_OR_PKCS12" = "ca" ]
              then
                  echo -e "ca $OPENVPN2_CLIENT_ONLY_CA_OR_PKCS12_FILE\r" >>/etc/openvpn/$client_name.conf
              fi
          fi

          (
          echo -e "dev $OPENVPN2_CLIENT_ONLY_IF_TYPE\r"
          if [ "$OPENVPN2_CLIENT_ONLY_ENABLE_SCRIPTSECURITY" != "0" -a "$OPENVPN2_CLIENT_ONLY_ENABLE_SCRIPTSECURITY" != "1" ]
          then
              echo -e "script-security $OPENVPN2_CLIENT_ONLY_ENABLE_SCRIPTSECURITY\r"
              if [ "$OPENVPN2_CLIENT_ONLY_SCRIPT" != "" ]
              then
                  echo -e "route-up $OPENVPN2_CLIENT_ONLY_SCRIPT\r"
              fi
          fi
          if [ "$OPENVPN2_CLIENT_ONLY_ENABLE_LEGACY_DEFAULT" = "yes" ]
          then
              echo -e "providers legacy default"
          fi
          echo -e "data-ciphers-fallback $OPENVPN2_CLIENT_ONLY_CIPHER\r"
          if [ "$OPENVPN2_CLIENT_ONLY_HMAC_AUTH" != "" ]
          then
              echo -e "auth $OPENVPN2_CLIENT_ONLY_HMAC_AUTH\r"
          fi
          if [ "$OPENVPN2_CLIENT_ONLY_COMPRESSION" != "" -a "$OPENVPN2_CLIENT_ONLY_COMPRESSION" != "no" ]
          then
              echo -e "compress $OPENVPN2_CLIENT_ONLY_COMPRESSION\r"
          fi
          echo -e "verb 3\r"
          if [ "$OPENVPN2_CLIENT_ONLY_CERT" = "remote-cert-tls" ]
          then
              echo -e "remote-cert-tls server\r"
          elif [ "$OPENVPN2_CLIENT_ONLY_CERT" = "ns-cert-type server" ]
          then
              echo -e "ns-cert-type server\r"
              
          fi
          if [ "$OPENVPN2_CLIENT_ONLY_IPV4_LAN" = "yes" ]
          then
              if [ "$OPENVPN2_CLIENT_ONLY_REDIRECT_IPV4" = "yes" ]
              then
                  echo -e "redirect-gateway\r"
              fi
              if [ "$OPENVPN2_CLIENT_ONLY_IPV4_ROUTE" != "" ]
              then
                  echo -e "route $OPENVPN2_CLIENT_ONLY_IPV4_ROUTE $OPENVPN2_CLIENT_ONLY_IPV4_NET $OPENVPN2_CLIENT_ONLY_IPV4_ROUTE_DEST $OPENVPN2_CLIENT_ONLY_IPV4_ROUTE_METRIC\r"
              fi 
          else
              echo -e "pull-filter ignore \"route \"\r"
          fi

          if [ "$OPENVPN2_CLIENT_ONLY_IPV6_LAN" = "yes" ]
          then
              if [ "$OPENVPN2_CLIENT_ONLY_REDIRECT_IPV6" = "yes" ]
              then
                  echo -e "redirect-gateway ipv6\r"
              fi
          else
              echo -e "pull-filter ignore \"ifconfig-ipv6\"\r"
              echo -e "pull-filter ignore \"route-ipv6\"\r"
          fi

          ) >$tmp_file
          cat $tmp_file >>/etc/openvpn/$client_name.conf
      fi
}


_client ()
{
  if [ "$c1" != "" ]
  then
      client_name=$c1
      client_type='windows'
      client_v6w=no
      client_v6l=no
      client_v4w=yes
      client_v4l=yes
      client_redirect4=no
      client_redirect6=no
      client_lp='1194'
      client_proxy=no
      client_proxytype=http
      client_proxyauth=no
      client_authtype=basic
      client_proxyuser=user
      client_proxypass=passw
      client_proxyip='192.0.0.1'
      client_proxyport=8080
      client_scripten=no
      client_script='path/to/script'
      client_v4route=''
      client_v6route=''
      client_proxyauthfile=''
      NUMMER=`grep -w $client_name /etc/config.d/openvpn2 | grep NAME | awk -F"_" '{print $3}'`
      if [ "$NUMMER" = "" ]
      then
          NUMMER='1'
      fi
      OHNE_MENU='1'
      OPENVPN2_CLIENT_N=1
  else
      NUMMER='1'      
      OHNE_MENU='0'

  fi

  while [ $NUMMER -le $OPENVPN2_CLIENT_N ]
  do
      if [ "$OHNE_MENU" = "0" ]
      then
          eval client_name='$OPENVPN2_CLIENT_'$NUMMER'_NAME'
          eval client_active='$OPENVPN2_CLIENT_'$NUMMER'_ACTIVE'
      else
          client_active='yes'
      fi
      eval client_type='$OPENVPN2_CLIENT_'$NUMMER'_TYPE'
      eval client_v4l='$OPENVPN2_CLIENT_'$NUMMER'_IPV4_LAN'
      eval client_v4w='$OPENVPN2_CLIENT_'$NUMMER'_IPV4_WAN'
      eval client_v6l='$OPENVPN2_CLIENT_'$NUMMER'_IPV6_LAN'
      eval client_v6w='$OPENVPN2_CLIENT_'$NUMMER'_IPV6_WAN'
      eval client_redirect4='$OPENVPN2_CLIENT_'$NUMMER'_REDIRECT_IPV4'
      eval client_redirect6='$OPENVPN2_CLIENT_'$NUMMER'_REDIRECT_IPV6'
      eval client_lp='$OPENVPN2_CLIENT_'$NUMMER'_USE_LOCALPORT'
      eval client_proxy='$OPENVPN2_CLIENT_'$NUMMER'_USE_PROXY'
      eval client_proxytype='$OPENVPN2_CLIENT_'$NUMMER'_PROXY'
      eval client_proxyauth='$OPENVPN2_CLIENT_'$NUMMER'_PROXY_AUTH'
      eval client_authtype='$OPENVPN2_CLIENT_'$NUMMER'_PROXY_AUTH_TYPE'
      eval client_proxyuser='$OPENVPN2_CLIENT_'$NUMMER'_PROXY_AUTH_USERNAME'
      eval client_proxyip='$OPENVPN2_CLIENT_'$NUMMER'_PROXY_IP'
      eval client_proxyport='$OPENVPN2_CLIENT_'$NUMMER'_PROXY_PORT'
      eval client_proxypass='$OPENVPN2_CLIENT_'$NUMMER'_PROXY_AUTH_PASSWORD'
      eval client_scripten='$OPENVPN2_CLIENT_'$NUMMER'_ENABLE_SCRIPTSECURITY'
      eval client_legacyen='$OPENVPN2_CLIENT_'$NUMMER'_ENABLE_LEGACY_DEFAULT'
      eval client_script='$OPENVPN2_CLIENT_'$NUMMER'_SCRIPT'
      eval client_v4route='$OPENVPN2_CLIENT_'$NUMMER'_IPV4_ROUTE'
      eval client_v4routen='$OPENVPN2_CLIENT_'$NUMMER'_IPV4_NET'
      eval client_v4routed='$OPENVPN2_CLIENT_'$NUMMER'_IPV4_ROUTE_DEST'
      eval client_v4routem='$OPENVPN2_CLIENT_'$NUMMER'_IPV4_ROUTE_METRIC'
      eval client_v6route='$OPENVPN2_CLIENT_'$NUMMER'_IPV6_ROUTE'
      eval client_v6routed='$OPENVPN2_CLIENT_'$NUMMER'_IPV6_ROUTE_DEST'
      eval client_v6routem='$OPENVPN2_CLIENT_'$NUMMER'_IPV6_ROUTE_METRIC'
      eval client_proxyauthfile="/etc/openvpn/proxyauthfile_"$NUMMER

      if [ "$client_active" = "yes" ]
      then
          rm -f /usr/local/openvpn/conf/$client_name.conf
          mecho --info "create client config file for $client_name"
          # erstmal pruefen, ob ipv4 bzw ipv6 benoetigt wird
          if [ "$client_v4w" = "yes" -o "$client_v4l" = "yes" ]
          then
              NET4='yes'
          fi
          if [ "$client_v6w" = "yes" -o "$client_v6l" = "yes" ]
          then
              NET6='yes'
          fi
          # Create client-config-file
          tmp_file=$(/usr/bin/mktemp -t .XXXXXXXXXXXXX)
          (
          echo -e "#OpenVPN Client conf\r"
          echo -e "client\r"
          )> $tmp_file
          if [ "$client_lp" != "" ]
          then
              echo -e "lport $client_lp\r" >> $tmp_file
          fi
          cat $tmp_file >/usr/local/openvpn/conf/$client_name.conf
          cat $tmp_file >/usr/local/openvpn/conf/$client_name.ovpn

          if  [ "$client_v6w" = "yes" ]
          then
              (
              echo -e "<connection>\r"
              echo -e "remote $OPENVPN2_HOSTNAME $OPENVPN2_PORT $OPENVPN2_PROTOCOL"6"\r"
              _proxy
              echo -e "</connection>\r"          
              )>>/usr/local/openvpn/conf/$client_name.conf
          fi
          if  [ "$client_v4w" = "yes" ]
          then
              (
              echo -e "<connection>\r"
              echo -e "remote $OPENVPN2_HOSTNAME $OPENVPN2_PORT $OPENVPN2_PROTOCOL\r"
              _proxy
              echo -e "</connection>\r"
              echo -e "pkcs12 /usr/local/openvpn/keys/$client_name.p12\r"
              )>>/usr/local/openvpn/conf/$client_name.conf
          fi
          if  [ "$client_v6w" = "yes" -o "$client_v4w" = "yes" ]
          then
              (
              echo -e "remote $OPENVPN2_HOSTNAME\r"
              echo -e "port $OPENVPN2_PORT\r"
              echo -e "proto $OPENVPN2_PROTOCOL\r"
              echo -e "pkcs12 $client_name.p12\r"
              )>>/usr/local/openvpn/conf/$client_name.ovpn
          fi
          (
          echo -e "dev $OPENVPN2_SERVER_IF_TYPE\r"
          if [ "$client_scripten" != "0" -a "$client_scripten" != "1" ]
          then
              echo -e "script-security $client_scripten\r"
              if [ "$client_script" != "" ]
              then
                  echo -e "route-up $client_script\r"        
              fi
          fi
          if [ "$client_legacyen" = "yes" ]
          then
              echo -e "providers legacy default"
          fi

          echo -e "data-ciphers-fallback $OPENVPN2_CIPHER\r"
          if [ "$OPENVPN2_HMAC_AUTH" != "" ]
          then
              echo -e "auth $OPENVPN2_HMAC_AUTH\r"
          fi
          if [ "$OPENVPN2_COMPRESSION" != "" -a "$OPENVPN2_COMPRESSION" != "no" ]
          then
              echo -e "compress $OPENVPN2_COMPRESSION\r"
          fi
          echo -e "verb 3\r"
          if [ "$OPENVPN2_SERVER_CERT" = "remote-cert-tls" ]
          then
              echo -e "remote-cert-tls server\r"
          else
              echo -e "ns-cert-type server\r"
          fi

          # Besonderheiten fuer Windows-Clients

          if [ "$client_v4l" = "yes" ]
          then
              if [ "$client_redirect4" = "yes" ]
              then
                  if [ "$client_type" = "linux" ]
                  then
                      echo -e "redirect-gateway\r"
                  else
                     echo -e "redirect-gateway def1\r"
                  fi
              fi
              if [ "$client_v4route" != "" ]
              then
                  echo -e "route $client_v4route $client_v4routen $client_v4routed $client_v4routem\r"
              fi
          else
              echo -e "pull-filter ignore \"route \"\r"
          fi
          if [ "$client_v6l" = "yes" ]
          then
              if [ "$client_redirect6" = "yes" ]
              then
                  echo -e "redirect-gateway ipv6\r"
              fi
              if [ "$client_v6route" != "" ]
              then
                  echo -e "route-ipv6 $client_v6route $client_v6routed $client_v6routem\r"
              fi
          else
              echo -e "pull-filter ignore \"ifconfig-ipv6\"\r"
              echo -e "pull-filter ignore \"route-ipv6\"\r"
          fi
          ) >$tmp_file
          cat $tmp_file >>/usr/local/openvpn/conf/$client_name.ovpn
          cat $tmp_file >>/usr/local/openvpn/conf/$client_name.conf
          #cd /usr/local/openvpn/conf/
          #ln -sf $client_name.ovpn $client_name.conf

          if [ ! -f '/usr/local/openvpn/keys/'$client_name'.crt' ]
          then
              /var/install/bin/openvpn2-rsactrl clientcert $client_name
          fi
      fi
      if [ "$client_active" = "yes" -a "$OPENVPN2_CLIENT_ONLY_MODE" = "no" ]
      then
          if  ! grep -q $client_name $clientsfile 
          then
              echo "$client_name" >> $clientsfile
          fi
      elif [ "$client_active" = "no" -a "$OPENVPN2_CLIENT_ONLY_MODE" = "no" ]
      then
          if [ -f $clientsfile ]
          then
              if grep -wq $client_name $clientsfile
              then
                  sed -i "/"$client_name"/"d $clientsfile
              fi
          fi
          if [ -f /usr/local/openvpn/keys/$client_name.p12 ]
          then
              rm -f /usr/local/openvpn/conf/$client_name.*
              rm -f /usr/local/openvpn/keys/$client_name.*
          fi
      fi
  NUMMER=`/usr/bin/expr $NUMMER + 1`
  done


}


/usr/local/openvpn/create_vars.sh

    
if [ "$START_OPENVPN2" = "yes" ]
then
    # Create links for bootscripts
    mecho --info "enable boot links"
    service enable openvpn2
else
    # Remove links for bootscript
    mecho --warn "disable boot links"
    service disable openvpn2
fi


# create server config
_server ()
{
if [ "$OPENVPN2_SERVER_ACTIVE" = "yes" ]
then
    # create Export-directory
    mkdir -p $OPENVPN2_EXPORTDIR
    # init pki
    if [ ! -f /usr/local/openvpn/keys/ca.crt -o ! -f /usr/local/openvpn/keys/openvpn.crt ]
    then
        mecho --info "Zum aktivieren des Server muss zuerst eine CA und das\r\n" \
                  "Serverzertifikat erstellt werden. "
        mecho --info  "create CA-certificate"
        /var/install/bin/openvpn2-rsactrl initca
        mecho --info "create openvpn-Server-certificate"
        /var/install/bin/openvpn2-rsactrl servercert
    fi

    # create key links for ca and server
    LNSRC="/usr/local/openvpn/keys"
    LNDST="/etc/openvpn/keys"
    ln -sf $LNSRC/dh2048.pem $LNDST/dh2048.pem
    ln -sf $LNSRC/ca.crt $LNDST/ca.crt
    ln -sf $LNSRC/crl.pem $LNDST/crl.pem
    ln -sf $LNSRC/openvpn.crt $LNDST/openvpn.crt
    ln -sf $LNSRC/openvpn.key $LNDST/openvpn.key

    # create server.conf
    if [ ! -f /etc/openvpn/server.conf ]
    then
        mecho --info "creating server config file"
    else
        mecho --info "update server config file"
    fi
    (
    echo ";local $OPENVPN2_HOSTNAME"
    echo "dev $OPENVPN2_SERVER_IF_TYPE"
    echo "port $OPENVPN2_PORT"
    if [ "$OPENVPN2_SERVER_ENABLE_IPV6_WAN" = "yes" ]
    then
        echo "proto "$OPENVPN2_PROTOCOL"6"
    else
        echo "proto $OPENVPN2_PROTOCOL"
    fi
    echo "tls-server"
    echo "topology subnet"
    echo "ca /etc/openvpn/keys/ca.crt"
    echo "cert /etc/openvpn/keys/openvpn.crt"
    echo "key /etc/openvpn/keys/openvpn.key"
    echo "dh /etc/openvpn/keys/dh2048.pem"
    echo "server $OPENVPN2_IPV4_NET $OPENVPN2_IPV4_SUBNET"
    if [ "$OPENVPN2_SERVER_ENABLE_IPV6_LAN" = "yes" ]
    then
        echo "server-ipv6 $OPENVPN2_IPV6_NET "
        if [ "$client_redirect6" = "yes" ]
        then
            if [ "$OPENVPN2_SERVER_ENABLE_MSSFIX" != "" ]
            then
                echo -e "mssfix $OPENVPN2_SERVER_ENABLE_MSSFIX\r"
            fi
        fi
    fi
    echo "keepalive 10 60"
    echo "status-version 1"
    echo "status /var/log/openvpn/server.log 30"
    if [ "$OPENVPN2_APPEND_LOG" = "yes" ]
    then
        echo "log-append /var/log/openvpn/openvpn.log"
    fi
    if [ "$OPENVPN2_SERVER_ENABLE_LEGACY_DEFAULT" = "yes" ]
    then
        echo "providers legacy default"
    fi

    echo "data-ciphers-fallback $OPENVPN2_CIPHER"
    if [ "$OPENVPN2_HMAC_AUTH" != "" ]
    then
        echo "auth $OPENVPN2_HMAC_AUTH"
    fi
    if [ "$OPENVPN2_COMPRESSION" != "" -a "$OPENVPN2_COMPRESSION" != "no" ]
    then
        echo "compress $OPENVPN2_COMPRESSION"
    fi
    if [ "$OPENVPN2_SERVER_ENABLE_FLOAT" = "yes" ]
    then
        echo "float"
    fi
    echo "client-config-dir /etc/openvpn/ccd"
    echo "max-clients 100"
    echo "user nobody"
    echo "group nogroup"
    echo "persist-key"
    echo "persist-tun"
    echo "verb 3"
    if [ "$OPENVPN2_CLIENT_TO_CLIENT" = "yes" ]
    then
        echo "client-to-client"
    fi
    echo "ifconfig-pool-persist /etc/openvpn/ipp.txt"
    # Push-Optionen
    if [ $OPENVPN2_IPV4_PUSH_ROUTE_N -gt 0 ]
    then
        idx=1
        while [ $idx -le $OPENVPN2_IPV4_PUSH_ROUTE_N ]
        do
            eval push_net='$OPENVPN2_IPV4_PUSH_ROUTE_'$idx'_NET'
            eval push_subnet='$OPENVPN2_IPV4_PUSH_ROUTE_'$idx'_SUBNET'
            echo "push \"route $push_net $push_subnet\""
            idx=`/usr/bin/expr $idx + 1`
        done
    fi
    [ -z "$OPENVPN2_DHCP_DOMAIN" ] || echo "push \"dhcp-option DOMAIN $OPENVPN2_DHCP_DOMAIN\""
    [ -z "$OPENVPN2_IPV4_PUSH_DHCP_DNS" ] || echo "push \"dhcp-option DNS $OPENVPN2_IPV4_PUSH_DHCP_DNS\""
    [ -z "$OPENVPN2_IPV4_PUSH_DHCP_WINS" ] || echo "push \"dhcp-option WINS $OPENVPN2_IPV4_PUSH_DHCP_WINS\""

    if [ "$OPENVPN2_SERVER_ENABLE_IPV6_LAN" = "yes" ]
    then
        if [ $OPENVPN2_IPV6_PUSH_ROUTE_N -gt 0 ]
        then
            idx=1
            while [ $idx -le $OPENVPN2_IPV6_PUSH_ROUTE_N ]
            do
                eval push_net6='$OPENVPN2_IPV6_PUSH_ROUTE_'$idx'_NET'
                echo "push \"route-ipv6 $push_net6\""
                idx=`/usr/bin/expr $idx + 1`
            done
        fi
        [ -z "$OPENVPN2_IPV6_PUSH_DHCP_DNS" ] || echo "push \"dhcp-option DNS $OPENVPN2_IPV6_PUSH_DHCP_DNS\""
    fi

    ) > /etc/openvpn/server.conf
    touch /etc/openvpn/ipp.txt
else
    mecho --warn "removing server config file"
    rm -f /etc/openvpn/server.conf
fi
}


# create clients file and cert
_server
_client
_client_only
if [ "$START_OPENVPN2" = "yes" ]
then
    service start openvpn2
fi
exit 0
